import Taro from "@tarojs/taro";
import { View, Text } from '@tarojs/components'
import formatTime from "@/utils/formatTime";
import CouponCard from '@/components/CouponCard'
import QRcode from "@/assets/icons/UserCenter/QRcode.png";
import refund from "@/assets/icons/GuideCheck/refund.png";
import Pay from "@/assets/icons/GuideCheck/Pay_logo.png";
import Null from "@/assets/icons/UserCenter/null_logo.png";
import Evaluation from "@/assets/icons/UserCenter/Evaluation.png";
import './style.less'


const CouponMedia = CouponCard.Media
const Action = CouponCard.Action

export default (props) => {
  const { item, setShowCutover } = props

  const handleDetail = () => {
    if (item.status === 0) {
      Taro.navigateTo({
        url: `/pages/PayOrder/index?orderId=${item.orderId}`,
      });
    }
  }

  //核销
  const onWriteOff = (item) => {
    Taro.scanCode({
      onlyFromCamera: true,
      success: (res) => {
        if (res.path) {
          Taro.navigateTo({
            url: `/${res.path}&subOrderId=${item.subOrderId}`,
          });
        } else {
          Taro.showToast({
            title: "非当前小程序生成二维码",
            icon: "none",
            duration: 2000,
          });
        }
      },
      fail: (err) => {
      },
    });
  }
  //评价
  const evaluation = () => {
    setShowCutover(true)
  }
  const PayAction =
    item.status === 0 ? <Action.Icon icon={Pay} text='支付' onClick={handleDetail} /> :
      item.status === 1 && item.isVerified == 0 ? <Action.Icon icon={QRcode} text='扫码核销' onClick={() => onWriteOff(item)} /> :
        item.status === 2 && item.isVerified == 0 ? <Action.Image image={refund} /> :
          item.status === 9 ? <Action.Image image={Null} /> :
            item.isVerified == 1 ? <Action.Icon icon={Evaluation} text='评价' onClick={() => evaluation()} /> : ''

  return (
    <>
      <view className='OrderNumber'>订单编号：{item.orderId}</view>
      <CouponCard action={PayAction}>
        <CouponMedia>
          <CouponMedia.Header
            cashback={item.cashback}
            image={item.poster}
            badge='food'
          />
          <CouponMedia.Body star={item.score}>
            <View className='cpn-card-text'>
              <View style={{ flex: '1' }}>{(item.packageDescription).toString().length > 25 ? (item.packageDescription).substring(0, 25) + '...' : (item.packageDescription)}</View>
              <text className='title-money-2'>
                数量：{item.amount}张
              </text>
            </View>
            <View className='cpn-card-text' style={{ marginTop: '10rpx' }}>
              <Text className='cpn-card-text_mn'>￥{`${(item.unitPrice / 100)?.toFixed(2)}元`}</Text>
            </View>
            <View className='cpn-md-act'>
              <view className='title-time'>
                有效期：{formatTime(item?.startTime, "yyyy/MM/dd")}-
                {formatTime(item.endTime, "yyyy/MM/dd")}
              </view>
            </View>
          </CouponMedia.Body>
        </CouponMedia>
      </CouponCard>
    </>
  )
}