import React, { useState, useEffect } from "react";
import Taro, { useDidShow, AtSwipeAction } from "@tarojs/taro";
import { getOrderSub, deleteOrder } from "@/services/payOrder";
import NoData from '@/components/NoData'
import ico_delete from '../../../assets/icons/ProCard/ico_delete.png'
import AlreadyUsed from "../AlreadyUsed";
import OrderCard from '../OrderCard'
import "./style.less";
import { View } from "@tarojs/components";


const dict = {
  0: { status: 0, isVerified: 0 },
  1: { status: 1, isVerified: 0 },
  2: { isVerified: 1 },
  3: { status: 9, isVerified: 0 },
};
export default (props) => {
  const { type } = props;
  const [list, setList] = useState([]);
  const [IsPull, setPull] = useState(false);
  const [pageNum, setNumber] = useState(1);
  const [HasNextPage, setHasNextPage] = useState(true);

  useDidShow(() => {
    setNumber(1)
  })

  useEffect(() => {
    if (pageNum) {
      getList();
    }

  }, [pageNum]);

  const pageRefresh = () => {
    // 页面下拉刷新回调
    setPull(true);
  };

  const getList = () => {
    setHasNextPage(false);
    getOrderSub({
      pageNum,
      pageSize: 10,
      isVerified: '',
      ...(type !== undefined ? dict[type] : null),
    }).then((res) => {
      setList(
        pageNum === 1 ? res.records || [] : list.concat(res.records || [])
      );
      setHasNextPage(res.current < res.pages);
      setPull(false);
    });
  };

  const pageLoadMore = () => {
    // 页面上拉加载更多
    if (HasNextPage) {
      setNumber(pageNum + 1);
    }
  };

  const [showCutover, setShowCutover] = useState(false)

  const onClose = () => {
    setShowCutover(false)
  }

  useEffect(() => {
    // 下拉刷新触发
    if (IsPull) {
      if (pageNum === 1) {
        getList();
      } else {
        setNumber(1);
      }
    }
  }, [IsPull]);


  const slideButtonTap = (e) => {
    deleteOrder(e.orderId || '').then(() => {
      Taro.showToast({
        title: '删除订单成功',
        icon: 'none',
      })
      getList();
    })
  }

  const button = [{
    extClass: 'test-button',
    src: ico_delete
  }]

  return (
    <View style={{ height: 'calc(100% - 46px)' }}>
      <scroll-view
        scrollY
        style={{ height: '100%' }}
        refresher-enabled
        refresher-triggered={IsPull}
        onrefresherrefresh={pageRefresh}
        refresher-background='#fff'
        onscrolltolower={pageLoadMore}
      >
        {
          list.length == 0 ?
            <NoData /> :
            <view className='complete-boxs'>
              <AlreadyUsed showCutover={showCutover} maskClosable={showCutover} onClose={onClose} list={list} />
              {list.map((item, index) => {
                /* 待支付 */
                if (item.status === 0) {
                  return (
                    <mp-slideview buttons={button} onButtontap={() => slideButtonTap(item)} icon >
                      <view key={`${type}-${item.orderId}`}  >
                        <OrderCard item={item} />
                      </view>
                    </mp-slideview>
                  );
                }
                /* 已使用 */
                else if (item.isVerified == 1) {
                  return (
                    <view key={`${type}-${item.orderId}`}>
                      <OrderCard item={item} setShowCutover={setShowCutover} />
                    </view>
                  );
                }
                /* 待核销 */
                else {
                  return (
                    <view key={`${type}-${item.orderId}`}>
                      <OrderCard item={item} />
                    </view>
                  );
                }
              })}
              <view className='foot'>这是我的底线</view>
            </view>
        }
      </scroll-view>
    </View>
  )
};
